==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/StrongIdArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Property/Properties which represent a unique ID.
 * @property description Localized descriptions.
 * @property displayName Localized display name.
 * @property keyPropertyNames The properties which make up the unique ID.
 * @property strongIdName The Name identifying the strong ID.
 */
public data class StrongIdArgs(
    public val description: Output<Map<String, String>>? = null,
    public val displayName: Output<Map<String, String>>? = null,
    public val keyPropertyNames: Output<List<String>>,
    public val strongIdName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs> {
    override fun toJava(): com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs =
        com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs.builder()
            .description(
                description?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .displayName(
                displayName?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .keyPropertyNames(keyPropertyNames.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .strongIdName(strongIdName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StrongIdArgs].
 */
@PulumiTagMarker
public class StrongIdArgsBuilder internal constructor() {
    private var description: Output<Map<String, String>>? = null

    private var displayName: Output<Map<String, String>>? = null

    private var keyPropertyNames: Output<List<String>>? = null

    private var strongIdName: Output<String>? = null

    /**
     * @param value Localized descriptions.
     */
    @JvmName("vheeiyusojvwsjsw")
    public suspend fun description(`value`: Output<Map<String, String>>) {
        this.description = value
    }

    /**
     * @param value Localized display name.
     */
    @JvmName("ggchhgbvkwoaiwnm")
    public suspend fun displayName(`value`: Output<Map<String, String>>) {
        this.displayName = value
    }

    /**
     * @param value The properties which make up the unique ID.
     */
    @JvmName("pqtyjqldrdsvpjaa")
    public suspend fun keyPropertyNames(`value`: Output<List<String>>) {
        this.keyPropertyNames = value
    }

    @JvmName("upaxsgjhocvovjht")
    public suspend fun keyPropertyNames(vararg values: Output<String>) {
        this.keyPropertyNames = Output.all(values.asList())
    }

    /**
     * @param values The properties which make up the unique ID.
     */
    @JvmName("fdwpwkhbymtudvvn")
    public suspend fun keyPropertyNames(values: List<Output<String>>) {
        this.keyPropertyNames = Output.all(values)
    }

    /**
     * @param value The Name identifying the strong ID.
     */
    @JvmName("nifvmkxcoiqgymrb")
    public suspend fun strongIdName(`value`: Output<String>) {
        this.strongIdName = value
    }

    /**
     * @param value Localized descriptions.
     */
    @JvmName("yqbtkdacftjksmno")
    public suspend fun description(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param values Localized descriptions.
     */
    @JvmName("njaesupeafwydorq")
    public fun description(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Localized display name.
     */
    @JvmName("blnbpoiwiimbmbhx")
    public suspend fun displayName(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param values Localized display name.
     */
    @JvmName("jhaibuxquqrtlrhm")
    public fun displayName(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value The properties which make up the unique ID.
     */
    @JvmName("fbhyvambvdwrlqte")
    public suspend fun keyPropertyNames(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyPropertyNames = mapped
    }

    /**
     * @param values The properties which make up the unique ID.
     */
    @JvmName("wwjbxsdrpmlediru")
    public suspend fun keyPropertyNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyPropertyNames = mapped
    }

    /**
     * @param value The Name identifying the strong ID.
     */
    @JvmName("haswqvtagudqyppo")
    public suspend fun strongIdName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.strongIdName = mapped
    }

    internal fun build(): StrongIdArgs = StrongIdArgs(
        description = description,
        displayName = displayName,
        keyPropertyNames = keyPropertyNames ?: throw PulumiNullFieldException("keyPropertyNames"),
        strongIdName = strongIdName ?: throw PulumiNullFieldException("strongIdName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/StrongIdArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Property/Properties which represent a unique ID.
 * @property description Localized descriptions.
 * @property displayName Localized display name.
 * @property keyPropertyNames The properties which make up the unique ID.
 * @property strongIdName The Name identifying the strong ID.
 */
public data class StrongIdArgs(
    public val description: Output<Map<String, String>>? = null,
    public val displayName: Output<Map<String, String>>? = null,
    public val keyPropertyNames: Output<List<String>>,
    public val strongIdName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs> {
    override fun toJava(): com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs =
        com.pulumi.azurenative.customerinsights.inputs.StrongIdArgs.builder()
            .description(
                description?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .displayName(
                displayName?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .keyPropertyNames(keyPropertyNames.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .strongIdName(strongIdName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StrongIdArgs].
 */
@PulumiTagMarker
public class StrongIdArgsBuilder internal constructor() {
    private var description: Output<Map<String, String>>? = null

    private var displayName: Output<Map<String, String>>? = null

    private var keyPropertyNames: Output<List<String>>? = null

    private var strongIdName: Output<String>? = null

    /**
     * @param value Localized descriptions.
     */
    @JvmName("qtydfulgulvombpk")
    public suspend fun description(`value`: Output<Map<String, String>>) {
        this.description = value
    }

    /**
     * @param value Localized display name.
     */
    @JvmName("abolookslfuksfyo")
    public suspend fun displayName(`value`: Output<Map<String, String>>) {
        this.displayName = value
    }

    /**
     * @param value The properties which make up the unique ID.
     */
    @JvmName("xmesvsqwmigosgmu")
    public suspend fun keyPropertyNames(`value`: Output<List<String>>) {
        this.keyPropertyNames = value
    }

    @JvmName("umwgwijqwecmabhi")
    public suspend fun keyPropertyNames(vararg values: Output<String>) {
        this.keyPropertyNames = Output.all(values.asList())
    }

    /**
     * @param values The properties which make up the unique ID.
     */
    @JvmName("jptsmqdmdnhlsfqh")
    public suspend fun keyPropertyNames(values: List<Output<String>>) {
        this.keyPropertyNames = Output.all(values)
    }

    /**
     * @param value The Name identifying the strong ID.
     */
    @JvmName("rdrvehcmraxxitop")
    public suspend fun strongIdName(`value`: Output<String>) {
        this.strongIdName = value
    }

    /**
     * @param value Localized descriptions.
     */
    @JvmName("tfhesebxvlrjtogp")
    public suspend fun description(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param values Localized descriptions.
     */
    @JvmName("tebcygchiiesuedy")
    public fun description(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Localized display name.
     */
    @JvmName("uancexwwtsunwejr")
    public suspend fun displayName(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param values Localized display name.
     */
    @JvmName("nfklelxqeontajuk")
    public fun displayName(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value The properties which make up the unique ID.
     */
    @JvmName("sprytobbjxrawmpx")
    public suspend fun keyPropertyNames(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyPropertyNames = mapped
    }

    /**
     * @param values The properties which make up the unique ID.
     */
    @JvmName("sbsrndtrnkxxhaft")
    public suspend fun keyPropertyNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyPropertyNames = mapped
    }

    /**
     * @param value The Name identifying the strong ID.
     */
    @JvmName("bsomqtfarphslbne")
    public suspend fun strongIdName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.strongIdName = mapped
    }

    internal fun build(): StrongIdArgs = StrongIdArgs(
        description = description,
        displayName = displayName,
        keyPropertyNames = keyPropertyNames ?: throw PulumiNullFieldException("keyPropertyNames"),
        strongIdName = strongIdName ?: throw PulumiNullFieldException("strongIdName"),
    )
}
